@@ -1,5 +1,5 @@
 <?php
-// mycssadmin ver 1.0.3
+// mycssadmin ver 1.0.4
 //  ------------------------------------------------------------------------ //
 //                   This module; Copyright (c) 2005 gusagi                  //
 //                        <http://good-tea.ddo.jp/trpg>                      //
@@ -60,14 +60,15 @@ foreach( $blocks as $key => $block) {
 			$redirect .= '?mid=' .$mid;
 		}
 		$block_css_field = 'BlockCssId' .$bid;
-		$css = addslashes( $myts->stripSlashesGPC(basename($_POST[$block_css_field])) );
+		$css = !empty( $_POST[$block_css_field] ) ?
+			addslashes( $myts->stripSlashesGPC(basename($_POST[$block_css_field])) ) : '';
 		// cssեʸĹå
 		if ( strlen($css) > $css_max_length ) {
 				redirect_header( $redirect, 2, sprintf(MYCSSADMIN_ERR_CSS_TOO_LONG, $css_max_length) );
 				exit;
 		}
 		// Ͽ
-		if ( empty($block['selected']) && !empty($_POST[$block_css_field]) ) {
+		if ( empty($block['selected']) && !empty($css) ) {
 			$sql = "INSERT INTO $cssadmin_blocks";
 			$sql .= " VALUES( $bid, $mid, '$css' )";
 			$result = $xoopsDB->query( $sql );
@@ -76,7 +77,7 @@ foreach( $blocks as $key => $block) {
 				exit;
 			}
 		// CSSϢդѹ
-		} elseif ( !empty($block['selected']) && !empty($_POST[$block_css_field]) 
+		} elseif ( !empty($block['selected']) && !empty($css) 
 				&& ($block['selected'] !== $_POST[$block_css_field]) ) {
 			$sql = "UPDATE $cssadmin_blocks SET";
 			$sql .= " css = '$css' ";
@@ -87,7 +88,7 @@ foreach( $blocks as $key => $block) {
 				exit;
 			}
 		// CSSϢդѻ߻
-		} elseif ( !empty($block['selected']) && empty($_POST[$block_css_field]) ) {
+		} elseif ( !empty($block['selected']) && empty($css) ) {
 			$sql = "DELETE FROM $cssadmin_blocks";
 			$sql .= " WHERE bid = $bid";
 			$result = $xoopsDB->query( $sql );
