@@ -1,5 +1,5 @@
 <?php
-// mycssadmin ver 1.0.3
+// mycssadmin ver 1.0.4
 //  ------------------------------------------------------------------------ //
 //                   This module; Copyright (c) 2005 gusagi                  //
 //                        <http://good-tea.ddo.jp/dev>                       //
@@ -10,20 +10,25 @@
 //*****************************************************************************/ 
 if( ! defined( 'XOOPS_ROOT_PATH' ) ) exit ;
 
-if( ! class_exists( 'CssadminUtility' ) ) {
+if( ! class_exists( 'MyCssadminUtility' ) ) {
 
-class CssadminUtility {
+class MyCssadminUtility {
 
 	/**
-	 * CssadminUtility
+	 * MyCssadminUtility
 	 * 
 	 * @param void
 	 * @return void
 	 */
-	function CssadminUtility() {
+	function MyCssadminUtility() {
 	}
 
-
+	/**
+	 * getBlockArray
+	 * 
+	 * @param void
+	 * @return void
+	 */
 	function getBlockArray() {
 		// 
 		global $xoopsModule,$xoopsUser,$xoopsConfig;
